cal.Guest (Presence) — amici1

# `cal.Guest` (Presence)

Guest(id, event, partner, role, state, remark)

Master tables : cal.AllGuests (Presences), cal.Guests (Presences), cal.MyGuests (My guests), cal.MyPendingPresences (My pending invitations), cal.MyPresences (My presences)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Calendar entry (event) : The calendar event to which this presence applies.

- Person (partner) : The partner to which this presence applies.

- Role (role) : The role of this partner in this presence.

- State (state) : The state of this presence. See GuestStates.

- Remark (remark) : See `<django.db.models.fields.CharField: remark>`.

- Calendar entry (event_summary) : See `lino_xl.lib.cal.models.Guest.event_summary`.

- Name (name_column) : See `lino_xl.lib.cal.models.Guest.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.cal.models.Guest.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.cal.models.Guest.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
id | ID |
event | Calendar entry | The calendar event to which this presence applies.
partner | Person | The partner to which this presence applies.
role | Role | The role of this partner in this presence.
state | State | The state of this presence. See GuestStates.
remark | Remark |
event_summary | Calendar entry |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |